from pysmarthome.db import s3db
from pysmarthome.devices import Pc, Tv, GoveeLedStrip
from pysmarthome.devices import SonoffDevice

db = s3db(bucket_name='pysmarthome', enc='json')
# print(db.collections['devices'].documents)
# print('----------------')
# print(db.collections['devices_states'].documents)


#print(db.collections['devices_states'].documents)
#db.delete('cf18cd44-cba4-4a33-984d-7cd2122816ba', 'devices_states')
#pc = Pc.create(db, name='test-creation')

#Pc.load(db, id='62d4e379-8a96-4f89-b0d9-96d02f391a14')
# print('PC DICT: ', pc.to_dict())
# print('STATE DICT: ', pc.state.to_dict())
# 
# print('deleting.....')
# pc.delete()
# 
# db.collections['devices'].load_documents()
# db.collections['devices_states'].load_documents()
# 
# print(db.collections['devices'].documents)
# print('----------------')
# print(db.collections['devices_states'].documents)



from pysmarthome.db import s3db
from pysmarthome import config
from pysmarthome.managers.devices import DevicesManager
import time
db = s3db(**config['s3db'], enc='json')
manager = DevicesManager(db)

time.sleep(3)
print('start triggering...')

y = manager.load_device('f25eb2e4-fec9-48a7-820f-620a36c894ce', 'yeelight')
y.trigger_action('off')

s = manager.load_device('052905c5-3b67-4961-9f3b-c2fbc7cc3c3b', 'sonoff')
s.trigger_action('off')

salt = manager.load_device('407e6a41-5ad2-4a8f-bc5e-c10a98f0b387', 'sonoff')
salt.trigger_action('off')

print(y.to_dict())
print(s.to_dict())
print(salt.to_dict())



from pysmarthome.db import s3db
from pysmarthome.managers.devices import DevicesManager
import time

db = s3db(bucket_name='pysmarthome', encoder='json')

manager = DevicesManager(db)
manager.load_controllers()

tv = manager.load_device('67b0cbe0-9ac3-4265-8a79-90c696f5de5e', 'tv')
# floor_lamp = manager.load_device('9ade5102-5232-4a54-8cf3-9c77d12eb8a8', 'broadlink_rgb_lamp')
#ac = manager.load_device('1de3ed56-c6f2-4c08-a34e-9fe1bfe416cf', 'ac')
# y = manager.load_device('f25eb2e4-fec9-48a7-820f-620a36c894ce', 'yeelight')
# s = manager.load_device('052905c5-3b67-4961-9f3b-c2fbc7cc3c3b', 'sonoff')
# salt = manager.load_device('407e6a41-5ad2-4a8f-bc5e-c10a98f0b387', 'sonoff')
# table_a = manager.load_device('66a6144c-99f6-4d38-a398-a82c11ea7fb3', 'govee')
# table_b = manager.load_device('5ad63d22-e22c-4ccb-ab45-83a0eef8d5ad', 'govee')
# led_tv = manager.load_device('54704389-dcfe-4c73-82cc-4b707c21bf79', 'govee')
# monitors = manager.load_device('2e08bfa0-e9be-4da1-ac1e-33d5d3418d10', 'govee')

#print('start triggering...')
#q = 'off'
#
#t = 4
#print(f'wait for {t} seconds...')
#time.sleep(t)

# led_tv.trigger_action(q)
# table_a.trigger_action(q)
# table_b.trigger_action(q)
# monitors.trigger_action(q)
# y.trigger_action(q)
# salt.trigger_action(q)
# s.trigger_action(q)
# floor_lamp.trigger_action(q)
# tv.trigger_action(q)
#tv.model.state.update(state={'volume': 24})
tv.vol(13)
print(tv.state.to_dict())


#docs = db.collections['devices']._documents
#states = db.collections['devices_states']._documents
#print(docs, states)
#for d in docs:
#    if d in states:
#        print(docs[d]['name'], states[d]['state']['power'])



from vesla_pymvc import Model
from .refs_model import RefModel


class DeviceStatesModel(Model):
    schema = {
        **Model.schema,
        'state': {
            'type': 'dict',
            'default': {},
            'required': True,
            'schema': {
                'power': {
                    'type':  'string',
                    'allowed': ['on', 'off'],
                    'default': 'off',
                    'required': True
                },
            }
        }
    }


class DevicesModel(Model):
    schema = {
        **Model.schema,
        'name': {
            'type': 'string',
            'required': True,
        },
        'addr': { 'type': 'string' },
        'ping_cmd': { 'type': 'string' },
        'mac_addr': { 'type': 'string' },
        'api_key': { 'type': 'string' },
    }
    children_model_classes = {
        'state':  { 'class': DeviceStatesModel },
        'collection_ref': { 'class': RefModel.clone('DevicesRefModel') },
    }



import importlib
from . import Controller
from ..models import PluginsModel

class PluginController(Controller):
    model_class = PluginsModel

    @property
    def device_controllers(self): return self.module.device_controllers

    def __init__(self):
        self.module = None


    def on_load(self, module_name='', **data):
        self.module = importlib.import_module(module_name)
        self.module.on_load(**data['config'])


    def install(self):
        pass



from pysmarthome.db import s3db
from pysmarthome import config
import json
import os

db = s3db(**config['s3db'], enc='json')
configs = db.collections['api_configs']
print(configs.documents)

# dirname = os.path.abspath(os.path.dirname(__file__))
# devices_states_file = os.path.join(dirname, '..', 'data', 'devices_states.json')
# 
# with open(devices_states_file) as f:
#     states = json.load(f)
# 
# devices_states.documents = states
# 
# devices_states.update('67b0cbe0-9ac3-4265-8a79-90c696f5de5e', state={'power': 'on'})
#devices_states.load_documents()
#print(devices_states.documents)



from setuptools import setup, find_packages

setup(
    name='pysmarthome_lib',
    description='A python lib that abstracts pysmarthome entities',
    version='0.1.3',
    author='Filipe Alves',
    author_email='filipe.alvesdefernando@gmail.com',
    install_requires=[
        'vesla_pymvc',
    ],
    packages=find_packages(),
    url='https://github.com/filipealvesdef/pysmarthome/tree/master/pysmarthome-lib',
    zip_safe=False,
)



from pysmarthome.db import s3db
from pysmarthome import config
from pysmarthome.managers.devices import DevicesManager
import time

print('loading db')
db = s3db(**config['s3db'], enc='json')

print('initializing the devices')
manager = DevicesManager(db)

tv = manager.load_device('67b0cbe0-9ac3-4265-8a79-90c696f5de5e', 'tv')
floor_lamp = manager.load_device('9ade5102-5232-4a54-8cf3-9c77d12eb8a8', 'broadlink_rgb_lamp')
ac = manager.load_device('1de3ed56-c6f2-4c08-a34e-9fe1bfe416cf', 'ac')
y = manager.load_device('f25eb2e4-fec9-48a7-820f-620a36c894ce', 'yeelight')
s = manager.load_device('052905c5-3b67-4961-9f3b-c2fbc7cc3c3b', 'sonoff')
salt = manager.load_device('407e6a41-5ad2-4a8f-bc5e-c10a98f0b387', 'sonoff')
table_a = manager.load_device('66a6144c-99f6-4d38-a398-a82c11ea7fb3', 'govee')
table_b = manager.load_device('5ad63d22-e22c-4ccb-ab45-83a0eef8d5ad', 'govee')
led_tv = manager.load_device('54704389-dcfe-4c73-82cc-4b707c21bf79', 'govee')
monitors = manager.load_device('2e08bfa0-e9be-4da1-ac1e-33d5d3418d10', 'govee')

docs = db.collections['devices']._documents
states = db.collections['devices_states']._documents
for d in docs:
    if d in states:
        print(docs[d]['name'], states[d]['state'])

t = 5
print(f'wait for {t} seconds...')
time.sleep(t)
print('start triggering...')

q = 'on'
tv.trigger_action('mute')
tv.trigger_action('vol_down')
tv.trigger_action('vol_down')
# tv.trigger_action('mute')
#led_tv.trigger_action(q)
#table_a.trigger_action(q)
# ac.trigger_action(q)
#table_b.trigger_action(q)
# monitors.trigger_action(q)
#floor_lamp.trigger_action(q)
# tv.trigger_action(q)
#y.trigger_action(q)
# salt.trigger_action(q)
# s.trigger_action(q)

print(f'wait for {t} seconds...')
time.sleep(t)

docs = db.collections['devices']._documents
states = db.collections['devices_states']._documents
for d in docs:
    if d in states:
        print(docs[d]['name'], states[d]['state'])



from pysmarthome.db import s3db
from pysmarthome.managers.devices import DevicesManager
import time

db = s3db(bucket_name='pysmarthome', enc='json')
manager = DevicesManager(db)

tv = manager.load_device('67b0cbe0-9ac3-4265-8a79-90c696f5de5e', 'tv')
manager.load_devices()


t = 4
print(f'wait for {t} seconds...')
time.sleep(t)

print('start triggering...')
manager.get_device(name='pc_lamp').trigger_action('off')
manager.get_device(name='lava_lamp').trigger_action('off')
manager.get_device(name='floor_lamp').trigger_action('off')
manager.get_device(name='led_table_a').trigger_action('off')
manager.get_device(name='led_table_b').trigger_action('off')
manager.get_device(name='led_tv').trigger_action('off')
manager.get_device(name='led_monitors').trigger_action('off')
manager.get_device(name='q6fn').trigger_action('off')
manager.get_device(name='vesla00').trigger_action('pause')
docs = db.collections['devices']._documents
states = db.collections['devices_states']._documents
print(docs, states)
for d in docs:
    if d in states:
        print(docs[d]['name'], states[d]['state'])

t = 10
print(f'shutting down in {t} seconds...')
manager.get_device(name='vesla00').trigger_action('off')

